@@ -637,15 +637,14 @@ def update_app_utils(appname, branch, keys=False, reboot=False):
     CONFIG_DIR = "config/"
     ENV_DIR = "environments/"
     KEY_DIR = ("keys/" + ENVIRONMENT) if (keys in TRUTH_VALUES) else ""
-    CERTS_DIR = "certs/"
-    DIRS_TO_TAR = CONFIG_DIR + " " + ENV_DIR + " " + KEY_DIR + CERTS_DIR
+    DIRS_TO_TAR = CONFIG_DIR + " " + ENV_DIR + " " + KEY_DIR
 
     # If it's a shared utils repo, need to reach down into this app's directory
     if os.path.isdir(APP_UTILS_DIR):
         with lcd(APP_UTILS_DIR+"/"):
-            local('git archive %s --format=tar.gz --output=../%s.tar.gz %s %s %s %s' % (branch, TAR_NAME, CONFIG_DIR, ENV_DIR, KEY_DIR, CERTS_DIR)) 
+            local('git archive %s --format=tar.gz --output=../%s.tar.gz %s %s %s' % (branch, TAR_NAME, CONFIG_DIR, ENV_DIR, KEY_DIR)) 
     else:
-        local('git archive %s --format=tar.gz --output=%s.tar.gz %s %s %s %s' % (branch, TAR_NAME, CONFIG_DIR, ENV_DIR, KEY_DIR, CERTS_DIR))
+        local('git archive %s --format=tar.gz --output=%s.tar.gz %s %s %s' % (branch, TAR_NAME, CONFIG_DIR, ENV_DIR, KEY_DIR))
 
 
     # and move the tarball to the destination and expand it
